@@ -6,15 +6,30 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
-sub libs
+if($^O eq 'openbsd')
 {
-  shift->SUPER::libs(@_) . (
-       $^O eq 'openbsd'
-    && !$Config{usethreads} 
-    && Alien::FFI->install_type eq 'share' 
-    ? ' /usr/lib/libpthread.a' : '');
+
+  *libs = sub
+  {
+    shift->SUPER::libs(@_) . (
+         $^O eq 'openbsd'
+      && !$Config{usethreads} 
+      && Alien::FFI->install_type eq 'share' 
+      ? ' /usr/lib/libpthread.a' : '');
+  }
+}
+
+if($^O eq 'MSWin32' && $Config{cc} =~ /cl(\.exe)?$/i)
+{
+  *libs = sub
+  {
+    my $libs = shift->SUPER::libs(@_);
+    $libs =~ s{-L}{/LIBPATH:}g;
+    $libs =~ s{-l([A-Za-z]+)}{$1.LIB}g;
+    $libs;
+  }
 }
 
 
@@ -32,7 +47,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -50,20 +65,26 @@ In your C<Build.PL>:
  
  $build->create_build_script;
 
-In your L<FFI::Raw> script:
-
- use Alien::FFI;
- use FFI::Raw;
- 
- my($dll) = Alien::FFI->dynamic_libs;
- FFI::Raw->new($dll, '...', ...);
-
 =head1 DESCRIPTION
 
 This distribution installs libffi so that it can be used by other Perl distributions.  If already
 installed for your operating system, and it can be found, this distribution will use the libffi
 that comes with your operating system, otherwise it will download it from the Internet, build and
-install it fro you.
+install it for you.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<FFI::Platypus>
+
+Write Perl bindings to non-Perl libraries without C or XS
+
+=item L<FFI::CheckLib>
+
+Check that a library is available for FFI
+
+=back
 
 =head1 AUTHOR
 
